@@ -1,14 +1,28 @@
+import threading
 import weakref
 
 from snmp.ber import ParseError, decode_identifier
 from snmp.exception import *
-from snmp.pdu.v2 import *
+from snmp.pdu import *
 from snmp.security import *
 from snmp.security.levels import noAuthNoPriv
 from snmp.types import *
 from snmp.utils import *
 from . import MessageProcessingModel
 
+pduTypes = {
+    cls.TYPE: cls for cls in (
+        GetRequestPDU,
+        GetNextRequestPDU,
+        ResponsePDU,
+        SetRequestPDU,
+        GetBulkRequestPDU,
+        InformRequestPDU,
+        SNMPv2TrapPDU,
+        ReportPDU,
+    )
+}
+
 class InvalidMessage(IncomingMessageError):
     pass
 
@@ -240,13 +254,13 @@ class SNMPv3Message:
 class MessageProcessor:
     VERSION = MessageProcessingModel.SNMPv3
 
-    def __init__(self, lockType=DummyLock):
-        self.cacheLock = lockType()
+    def __init__(self):
+        self.cacheLock = threading.Lock()
         self.credentials = {}
         self.generator = NumberGenerator(31, signed=False)
         self.outstanding = {}
 
-        self.securityLock = lockType()
+        self.securityLock = threading.Lock()
         self.defaultSecurityModel = None
         self.securityModules = {}
 
